@@ -27,8 +27,6 @@ import asynchat
 import socket
 import constants
 
-logger = logging.getLogger('gourd')
-
 
 class RouteMgr(object):
     """
@@ -70,14 +68,17 @@ class TcpServer(asyncore.dispatcher, RouteMgr):
     _backlog = None
     _terminator = None
 
-    def __init__(self):
+    logger = None
+
+    def __init__(self, name=None):
         # 把map变成私有的
         asyncore.dispatcher.__init__(self, map=dict())
         RouteMgr.__init__(self)
+        self.logger = logging.getLogger(name or constants.DEFAULT_NAME)
 
     def handle_accept(self):
         sock, address = self.accept()
-        logger.debug('accept. socket:%s, address:%s', sock, address)
+        self.logger.debug('accept. socket:%s, address:%s', sock, address)
         TcpRequestHandler(self, address, self._terminator, sock, self._map)
 
     def _init_socket(self):
@@ -119,35 +120,35 @@ class TcpRequestHandler(asynchat.async_chat):
         try:
             self._json_data = json.loads(self._raw_data)
         except Exception, e:
-            logger.error('json parse fail. e: %s, recv_data: %s', e, self._raw_data)
+            self._server.logger.error('json parse fail. e: %s, recv_data: %s', e, self._raw_data)
             return
 
-        logger.debug('jdata: %s', self._json_data)
+        self._server.logger.debug('jdata: %s', self._json_data)
 
         if not isinstance(self._json_data, dict):
-            logger.error('json_data is not dict. json_data: %s', self._json_data)
+            self._server.logger.error('json_data is not dict. json_data: %s', self._json_data)
             return
 
         if not self._json_data.get('endpoint'):
-            logger.error('endpoint is not in json_data. json_data: %s', self._json_data)
+            self._server.logger.error('endpoint is not in json_data. json_data: %s', self._json_data)
             return
 
         endpoint = self._json_data['endpoint']
         view_func = self.server.get_view_func(endpoint)
         if not view_func:
-            logger.error('endpoint is not valid. endpoint: %s', endpoint)
+            self._server.logger.error('endpoint is not valid. endpoint: %s', endpoint)
             return
 
         try:
             view_func(self)
         except Exception, e:
-            logger.error('view_func raise exception. endpoint: %s, view_func: %s, e: %s',
+            self._server.logger.error('view_func raise exception. endpoint: %s, view_func: %s, e: %s',
                          endpoint, view_func.__name__, e)
 
     def handle_close(self):
         # 对端关闭链接，或者自己关闭链接时，调用
         asynchat.async_chat.handle_close(self)
-        logger.debug('socket closed')
+        self._server.logger.debug('socket closed')
 
     @property
     def server(self):
@@ -180,39 +181,42 @@ class UdpServer(asyncore.dispatcher, RouteMgr):
     _host = None
     _port = None
 
-    def __init__(self):
+    logger = None
+
+    def __init__(self, name=None):
         # 把map变成私有的
         asyncore.dispatcher.__init__(self, map=dict())
         RouteMgr.__init__(self)
+        self.logger = logging.getLogger(name or constants.DEFAULT_NAME)
 
     def handle_read(self):
         self._raw_data, self._address = self.socket.recvfrom(constants.DEFAULT_PACKAGE_SIZE)
         try:
             self._json_data = json.loads(self._raw_data)
         except Exception, e:
-            logger.error('json parse fail. e: %s, recv_data: %s', e, self._raw_data)
+            self.logger.error('json parse fail. e: %s, recv_data: %s', e, self._raw_data)
             return
 
-        logger.debug('jdata: %s', self._json_data)
+        self.logger.debug('jdata: %s', self._json_data)
 
         if not isinstance(self._json_data, dict):
-            logger.error('json_data is not dict. json_data: %s', self._json_data)
+            self.logger.error('json_data is not dict. json_data: %s', self._json_data)
             return
 
         if not self._json_data.get('endpoint'):
-            logger.error('endpoint is not in json_data. json_data: %s', self._json_data)
+            self.logger.error('endpoint is not in json_data. json_data: %s', self._json_data)
             return
 
         endpoint = self._json_data['endpoint']
         view_func = self.server.get_view_func(endpoint)
         if not view_func:
-            logger.error('endpoint is not valid. endpoint: %s', endpoint)
+            self.logger.error('endpoint is not valid. endpoint: %s', endpoint)
             return
 
         try:
             view_func(self)
         except Exception, e:
-            logger.error('view_func raise exception. endpoint: %s, view_func: %s, e: %s',
+            self.logger.error('view_func raise exception. endpoint: %s, view_func: %s, e: %s',
                          endpoint, view_func.__name__, e)
 
     def _init_socket(self):
